#! /usr/bin/env python
# -*- coding: utf-8 -*-

"""
Module that contains tests for solstice-config
"""

import pytest

from solstice.config import __version__


def test_version():
    assert __version__.__version__
